@@ -22,7 +22,8 @@
 
 // Qt includes
 #include <QFont>
-#include <QDebug>
+#include <QTimer>
+#include "libdiscover_debug.h"
 
 // KDE includes
 #include <KFormat>
@@ -36,12 +37,17 @@
 
 UpdateModel::UpdateModel(QObject *parent)
     : QAbstractListModel(parent)
+    , m_updateSizeTimer(new QTimer(this))
     , m_updates(nullptr)
 {
     connect(ResourcesModel::global(), &ResourcesModel::fetchingChanged, this, &UpdateModel::activityChanged);
     connect(ResourcesModel::global(), &ResourcesModel::updatesCountChanged, this, &UpdateModel::activityChanged);
     connect(ResourcesModel::global(), &ResourcesModel::resourceDataChanged, this, &UpdateModel::resourceDataChanged);
     connect(this, &UpdateModel::toUpdateChanged, this, &UpdateModel::updateSizeChanged);
+
+    m_updateSizeTimer->setInterval(100);
+    m_updateSizeTimer->setSingleShot(true);
+    connect(m_updateSizeTimer, &QTimer::timeout, this, &UpdateModel::updateSizeChanged);
 }
 
 UpdateModel::~UpdateModel() = default;
@@ -81,7 +87,7 @@ void UpdateModel::resourceHasProgressed(AbstractResource* res, qreal progress)
     item->setProgress(progress);
 
     const QModelIndex idx = indexFromItem(item);
-    Q_EMIT dataChanged(idx, idx, { ResourceProgressRole });
+    Q_EMIT dataChanged(idx, idx, { ResourceProgressRole, SectionResourceProgressRole });
 }
 
 void UpdateModel::activityChanged()
@@ -91,10 +97,11 @@ void UpdateModel::activityChanged()
             m_updates->prepare();
             setResources(m_updates->toUpdate());
 
-            for(auto item : m_updateItems) {
+            for(auto item : qAsConst(m_updateItems)) {
                 item->setProgress(0);
             }
-        }
+        } else
+            setResources(m_updates->toUpdate());
     }
 }
 
@@ -123,8 +130,16 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
         return item->progress();
     case ChangelogRole:
         return item->changelog();
-    case SectionRole:
-        return item->section();
+    case SectionRole: {
+        static const QString appUpdatesSection = i18nc("@item:inlistbox", "Application Updates");
+        static const QString systemUpdateSection = i18nc("@item:inlistbox", "System Updates");
+        switch(item->section()) {
+            case UpdateItem::ApplicationSection: return appUpdatesSection;
+            case UpdateItem::SystemSection: return systemUpdateSection;
+        }
+    } 
+    case SectionResourceProgressRole:
+        return (100-item->progress()) + (101 * item->section());
     default:
         break;
     }
@@ -209,8 +224,6 @@ void UpdateModel::setResources(const QList<AbstractResource*>& resources)
     qDeleteAll(m_updateItems);
     m_updateItems.clear();
 
-    const QString appUpdatesSection = i18nc("@item:inlistbox", "Application Updates");
-    const QString systemUpdateSection = i18nc("@item:inlistbox", "System Updates");
     QVector<UpdateItem*> appItems, systemItems;
     foreach(AbstractResource* res, resources) {
         connect(res, &AbstractResource::changelogFetched, this, &UpdateModel::integrateChangelog, Qt::UniqueConnection);
@@ -218,10 +231,10 @@ void UpdateModel::setResources(const QList<AbstractResource*>& resources)
         UpdateItem *updateItem = new UpdateItem(res);
 
         if(!res->isTechnical()) {
-            updateItem->setSection(appUpdatesSection);
+            updateItem->setSection(UpdateItem::ApplicationSection);
             appItems += updateItem;
         } else {
-            updateItem->setSection(systemUpdateSection);
+            updateItem->setSection(UpdateItem::SystemSection);
             systemItems += updateItem;
         }
     }
@@ -307,9 +320,9 @@ void UpdateModel::resourceDataChanged(AbstractResource* res, const QVector<QByte
 
     const auto index = indexFromItem(item);
     if (properties.contains("state"))
-        dataChanged(index, index, {SizeRole, VersionRole});
+        Q_EMIT dataChanged(index, index, {SizeRole, VersionRole});
     else if (properties.contains("size")) {
-        dataChanged(index, index, {SizeRole});
-        Q_EMIT updateSizeChanged();
+        Q_EMIT dataChanged(index, index, {SizeRole});
+        m_updateSizeTimer->start();
     }
 }
