@@ -24,6 +24,7 @@
 #include <QAbstractListModel>
 #include "discovercommon_export.h"
 
+class QTimer;
 class ResourcesUpdatesModel;
 class AbstractResource;
 class UpdateItem;
@@ -43,9 +44,11 @@ public:
         SizeRole,
         ResourceRole,
         ResourceProgressRole,
+        SectionResourceProgressRole,
         ChangelogRole,
         SectionRole
     };
+    Q_ENUM(Roles)
 
     explicit UpdateModel(QObject *parent = nullptr);
     ~UpdateModel() override;
@@ -91,6 +94,7 @@ private:
     void resourceHasProgressed(AbstractResource* res, qreal progress);
     void activityChanged();
 
+    QTimer* const m_updateSizeTimer;
     QVector<UpdateItem*> m_updateItems;
     ResourcesUpdatesModel* m_updates;
     QList<AbstractResource*> m_resources;
