@@ -31,6 +31,7 @@
 #include <PackageKit/Daemon>
 #include <QDBusInterface>
 #include <QFile>
+#include <QFileSystemWatcher>
 #include <KLocalizedString>
 #include <KDesktopFile>
 #include <KConfigGroup>
@@ -71,12 +72,21 @@ PackageKitNotifier::PackageKitNotifier(QObject* parent)
     } else
         regularCheck->start();
 
-	QTimer::singleShot(3000, this, &PackageKitNotifier::checkOfflineUpdates);
+    QTimer::singleShot(3000, this, &PackageKitNotifier::checkOfflineUpdates);
 
     m_recheckTimer = new QTimer(this);
     m_recheckTimer->setInterval(200);
     m_recheckTimer->setSingleShot(true);
     connect(m_recheckTimer, &QTimer::timeout, this, &PackageKitNotifier::recheckSystemUpdate);
+
+    QFileSystemWatcher* watcher = new QFileSystemWatcher(this);
+    watcher->addPath(QStringLiteral(PK_OFFLINE_ACTION_FILENAME));
+    connect(watcher, &QFileSystemWatcher::fileChanged, this, &PackageKitNotifier::nowNeedsReboot);
+
+    QTimer::singleShot(100, this, [this](){
+    if (QFile::exists(QStringLiteral(PK_OFFLINE_ACTION_FILENAME)))
+        nowNeedsReboot();
+    });
 }
 
 PackageKitNotifier::~PackageKitNotifier()
@@ -191,7 +201,7 @@ uint PackageKitNotifier::updatesCount()
 
 void PackageKitNotifier::onDistroUpgrade(PackageKit::Transaction::DistroUpgrade type, const QString& name, const QString& description)
 {
-#ifdef PKQT_0_10
+#ifdef PKQT_1_0
     KNotification *notification = new KNotification(QLatin1String("distupgrade-notification"), KNotification::Persistent | KNotification::DefaultEvent);
     notification->setIconName(QStringLiteral("system-software-update"));
     notification->setActions(QStringList{QLatin1String("Upgrade")});
@@ -211,6 +221,10 @@ void PackageKitNotifier::onDistroUpgrade(PackageKit::Transaction::DistroUpgrade
     });
 
     notification->sendEvent();
+#else
+    Q_UNUSED(type)
+    Q_UNUSED(name)
+    Q_UNUSED(description)
 #endif
 }
 
@@ -223,7 +237,7 @@ void PackageKitNotifier::refreshDatabase()
         });
     }
 
-#ifdef PKQT_0_10
+#ifdef PKQT_1_0
     if (!m_distUpgrades && (PackageKit::Daemon::roles() & PackageKit::Transaction::RoleUpgradeSystem)) {
         m_distUpgrades = PackageKit::Daemon::getDistroUpgrades();
         connect(m_distUpgrades, &PackageKit::Transaction::distroUpgrade, this, &PackageKitNotifier::onDistroUpgrade);
@@ -269,8 +283,12 @@ void PackageKitNotifier::transactionListChanged(const QStringList& tids)
         connect(t, &PackageKit::Transaction::requireRestart, this, &PackageKitNotifier::onRequireRestart);
         connect(t, &PackageKit::Transaction::finished, this, [this, t](){
             auto restart = t->property("requireRestart");
-            if (!restart.isNull())
-                requireRestartNotification(PackageKit::Transaction::Restart(restart.toInt()));
+            if (!restart.isNull()) {
+                auto restartEvent = PackageKit::Transaction::Restart(restart.toInt());
+                if (restartEvent >= PackageKit::Transaction::RestartSession) {
+                    nowNeedsReboot();
+                }
+            }
             m_transactions.remove(t->tid().path());
             t->deleteLater();
         });
@@ -278,39 +296,17 @@ void PackageKitNotifier::transactionListChanged(const QStringList& tids)
     }
 }
 
+void PackageKitNotifier::nowNeedsReboot()
+{
+    if (!m_needsReboot) {
+        m_needsReboot = true;
+        Q_EMIT needsRebootChanged();
+    }
+}
+
 void PackageKitNotifier::onRequireRestart(PackageKit::Transaction::Restart type, const QString &packageID)
 {
     PackageKit::Transaction* t = qobject_cast<PackageKit::Transaction*>(sender());
     t->setProperty("requireRestart", qMax<int>(t->property("requireRestart").toInt(), type));
     qDebug() << "RESTART" << type << "is required for package" << packageID;
 }
-
-void PackageKitNotifier::requireRestartNotification(PackageKit::Transaction::Restart type)
-{
-    if (type < PackageKit::Transaction::RestartSession) {
-        return;
-    }
-
-    KNotification *notification = new KNotification(QLatin1String("notification"), KNotification::Persistent | KNotification::DefaultEvent);
-    notification->setIconName(QStringLiteral("system-software-update"));
-    if (type == PackageKit::Transaction::RestartSystem || type == PackageKit::Transaction::RestartSecuritySystem) {
-        notification->setActions(QStringList{QLatin1String("Restart")});
-        notification->setTitle(i18n("Restart is required"));
-        notification->setText(i18n("The system needs to be restarted for the updates to take effect."));
-    } else {
-        notification->setActions(QStringList{QLatin1String("Logout")});
-        notification->setTitle(i18n("Session restart is required"));
-        notification->setText(i18n("You will need to log out and back in for the update to take effect."));
-    }
-
-    connect(notification, &KNotification::action1Activated, this, [type] () {
-        QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
-        if (type == PackageKit::Transaction::RestartSystem) {
-            interface.asyncCall(QStringLiteral("logout"), 0, 1, 2); // Options: do not ask again | reboot | force
-        } else {
-            interface.asyncCall(QStringLiteral("logout"), 0, 0, 2); // Options: do not ask again | logout | force
-        }
-    });
-
-    notification->sendEvent();
-}
