@@ -28,6 +28,8 @@
 #include <QJsonArray>
 #include <QDebug>
 
+const QStringList PackageKitResource::m_objects({ QStringLiteral("qrc:/qml/DependenciesButton.qml") });
+
 PackageKitResource::PackageKitResource(QString packageName, QString summary, PackageKitBackend* parent)
     : AbstractResource(parent)
     , m_summary(std::move(summary))
@@ -197,7 +199,7 @@ void PackageKitResource::setDetails(const PackageKit::Details & details)
         emit stateChanged();
 
         if (!backend()->isFetching())
-            backend()->resourcesChanged(this, {"size", "homepage", "license"});
+            Q_EMIT backend()->resourcesChanged(this, {"size", "homepage", "license"});
     }
 }
 
@@ -218,7 +220,7 @@ QString PackageKitResource::joinPackages(const QStringList& pkgids, const QStrin
 {
     QStringList ret;
     foreach(const QString& pkgid, pkgids) {
-        ret += i18nc("package-name (version)", "%1 (%2)", PackageKit::Daemon::packageName(pkgid), PackageKit::Daemon::packageVersion(pkgid));
+        ret += PackageKit::Daemon::packageVersion(pkgid);
     }
     const QString sep = _sep.isEmpty() ? i18nc("comma separating package names", ", ") : _sep;
     return ret.join(sep);
@@ -237,16 +239,16 @@ void PackageKitResource::updateDetail(const QString& /*packageID*/, const QStrin
                                       const QString& /*changelog*/, PackageKit::Transaction::UpdateState state, const QDateTime& /*issued*/, const QDateTime& /*updated*/)
 {
     QString info;
-    addIfNotEmpty(i18n("Reason:"), updateText, info);
+    addIfNotEmpty(i18n("Current Version:"), joinPackages(updates), info);
     addIfNotEmpty(i18n("Obsoletes:"), joinPackages(obsoletes), info);
-    addIfNotEmpty(i18n("Updates:"), joinPackages(updates), info);
+    addIfNotEmpty(i18n("New Version:"), updateText, info);
     addIfNotEmpty(i18n("Update State:"), PackageKitMessages::updateStateMessage(state), info);
     addIfNotEmpty(i18n("Restart:"), PackageKitMessages::restartMessage(restart), info);
 
     if (!vendorUrls.isEmpty())
         addIfNotEmpty(i18n("Vendor:"), urlToLinks(vendorUrls).join(QStringLiteral(", ")), info);
 
-    emit changelogFetched(info);
+    emit changelogFetched(changelog() + info);
 }
 
 PackageKitBackend* PackageKitResource::backend() const
