@@ -76,7 +76,7 @@ void PackageKitUpdater::prepare()
 
 void PackageKitUpdater::setupTransaction(PackageKit::Transaction::TransactionFlags flags)
 {
-    m_packagesRemoved.clear();
+    m_packagesModified.clear();
     auto pkgs = involvedPackages(m_toUpgrade).toList();
     pkgs.sort();
     m_transaction = PackageKit::Daemon::updatePackages(pkgs, flags);
@@ -178,24 +178,31 @@ void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time
     m_transaction = nullptr;
 
     if (!cancel && simulate) {
-        if (!m_packagesRemoved.isEmpty())
-            Q_EMIT proceedRequest(i18n("Packages to remove"), i18n("The following packages will be removed by the update:\n<ul><li>%1</li></ul>", PackageKitResource::joinPackages(m_packagesRemoved, QStringLiteral("</li><li>"))));
-        else {
+        const auto toremove = m_packagesModified.value(PackageKit::Transaction::InfoRemoving);
+        if (!toremove.isEmpty()) {
+            const auto toinstall = QStringList() << m_packagesModified.value(PackageKit::Transaction::InfoInstalling) << m_packagesModified.value(PackageKit::Transaction::InfoUpdating);
+            Q_EMIT proceedRequest(i18n("Packages to remove"), i18n("The following packages will be removed by the update:\n<ul><li>%1</li></ul>\nin order to install:\n<ul><li>%2</li></ul>",
+                                                                   PackageKitResource::joinPackages(toremove, QStringLiteral("</li><li>")),
+                                                                   PackageKitResource::joinPackages(toinstall, QStringLiteral("</li><li>"))
+                                                                  ));
+        } else {
             proceed();
         }
         return;
     }
 
     setProgressing(false);
-    m_backend->checkForUpdates();
+    m_backend->fetchUpdates();
     fetchLastUpdateTime();
 
-    if (qEnvironmentVariableIsSet("PK_OFFLINE_UPDATE"))
+    if (qEnvironmentVariableIsSet("PK_OFFLINE_UPDATE")) {
 #ifdef PKQT_1_0
         PackageKit::Daemon::global()->offline()->trigger(PackageKit::Offline::ActionReboot);
+        Q_EMIT passiveMessage(i18n("Please restart the computer to finish the installation"));
 #else
         qWarning() << "PK_OFFLINE_UPDATE is set but discover was built against an old version of PackageKitQt that didn't support offline updates";
 #endif
+    }
 }
 
 void PackageKitUpdater::cancellableChanged()
@@ -363,8 +370,7 @@ void PackageKitUpdater::updateDetail(const QString& packageID, const QStringList
 
 void PackageKitUpdater::packageResolved(PackageKit::Transaction::Info info, const QString& packageId)
 {
-    if (info == PackageKit::Transaction::InfoRemoving)
-        m_packagesRemoved << packageId;
+    m_packagesModified[info] << packageId;
 }
 
 void PackageKitUpdater::repoSignatureRequired(const QString& packageID, const QString& repoName, const QString& keyUrl,
