@@ -37,11 +37,32 @@
 #include <QThread>
 #include <QTimer>
 #include <QAction>
+#include <QStandardItemModel>
 
 #include "utils.h"
 
 DISCOVER_BACKEND_PLUGIN(SnapBackend)
 
+class SnapSourcesBackend : public AbstractSourcesBackend
+{
+public:
+    explicit SnapSourcesBackend(AbstractResourcesBackend * parent) : AbstractSourcesBackend(parent), m_model(new QStandardItemModel) {
+        m_model->appendRow(new QStandardItem(i18n("Snap")));
+    }
+
+    QAbstractItemModel* sources() override { return m_model; }
+    bool addSource(const QString& /*id*/) override { return false; }
+    bool removeSource(const QString& /*id*/) override { return false;}
+    QString idDescription() override { return QStringLiteral("Snap"); }
+    QList<QAction*> actions() const override { return {}; }
+
+    bool supportsAdding() const override { return false; }
+    bool canMoveSources() const override { return false; }
+
+private:
+    QStandardItemModel* const m_model;
+};
+
 SnapBackend::SnapBackend(QObject* parent)
     : AbstractResourcesBackend(parent)
     , m_updater(new StandardBackendUpdater(this))
@@ -61,7 +82,7 @@ SnapBackend::SnapBackend(QObject* parent)
     //make sure we populate the installed resources first
     refreshStates();
 
-    SourcesModel::global()->addBackend(this);
+    SourcesModel::global()->addSourcesBackend(new SnapSourcesBackend(this));
 }
 
 int SnapBackend::updatesCount() const
@@ -89,7 +110,9 @@ ResultsStream * SnapBackend::search(const AbstractResourcesBackend::Filters& fil
 
 ResultsStream * SnapBackend::findResourceByPackageName(const QUrl& search)
 {
-    return search.scheme() == QLatin1String("snap") ? populate(m_client.find(QSnapdClient::MatchName, search.host())) : voidStream();
+    return search.scheme() == QLatin1String("snap") ? populate(m_client.find(QSnapdClient::MatchName, search.host())) :
+           search.scheme() == QLatin1String("appstream") ? new ResultsStream(QLatin1String("snap-appstreamurl"), kFilter<QVector<AbstractResource*>>(m_resources, [search](SnapResource* res){ return res->appstreamId() == search.host(); } )) :
+                voidStream();
 }
 
 template <class T>
@@ -106,6 +129,7 @@ ResultsStream* SnapBackend::populate(T* job)
 
         QVector<AbstractResource*> ret;
         QSet<SnapResource*> resources;
+        resources.reserve(job->snapCount());
         for (int i=0, c=job->snapCount(); i<c; ++i) {
             QSharedPointer<QSnapdSnap> snap(job->snap(i));
             const auto snapname = snap->name();
@@ -124,7 +148,7 @@ ResultsStream* SnapBackend::populate(T* job)
             m_resources[res->packageName()] = res;
 
         if (!ret.isEmpty())
-            stream->resourcesFound(ret);
+            Q_EMIT stream->resourcesFound(ret);
         stream->finish();
     });
     job->runAsync();
@@ -178,7 +202,7 @@ void SnapBackend::refreshStates()
 {
     auto ret = new StoredResultsStream({populate(m_client.list())});
     connect(ret, &StoredResultsStream::finished, this, [this, ret](){
-        for (auto res: m_resources) {
+        for (auto res: qAsConst(m_resources)) {
             if (ret->resources().contains(res))
                 res->setState(AbstractResource::Installed);
             else
