@@ -69,15 +69,26 @@ QDebug operator<<(QDebug debug, const QSnapdSlot* slot)
     return debug;
 }
 
+const QStringList SnapResource::m_objects({ QStringLiteral("qrc:/qml/PermissionsButton.qml")
+#ifdef SNAP_CHANNELS
+	, QStringLiteral("qrc:/qml/ChannelsButton.qml")
+#endif
+	});
+
 SnapResource::SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::State state, SnapBackend* backend)
     : AbstractResource(backend)
     , m_state(state)
     , m_snap(snap)
-    , m_objects({ QStringLiteral("qrc:/snapui/PermissionsButton.qml") })
 {
     setObjectName(snap->name());
 }
 
+QSnapdClient * SnapResource::client() const
+{
+    auto backend = qobject_cast<SnapBackend*>(parent());
+    return backend->client();
+}
+
 QString SnapResource::availableVersion() const
 {
     return installedVersion();
@@ -110,8 +121,7 @@ QVariant SnapResource::icon() const
             if (!iconPath.startsWith(QLatin1Char('/')))
                 return QUrl(iconPath);
 
-            auto backend = qobject_cast<SnapBackend*>(parent());
-            auto req = backend->client()->getIcon(packageName());
+            auto req = client()->getIcon(packageName());
             connect(req, &QSnapdGetIconRequest::complete, this, &SnapResource::gotIcon);
             req->runAsync();
             return {};
@@ -215,12 +225,6 @@ bool SnapResource::isTechnical() const
     return m_snap->snapType() != QLatin1String("app");
 }
 
-QUrl SnapResource::url() const
-{
-    //FIXME interim, until it has an appstreamId
-    return QUrl(QStringLiteral("snap://") + packageName());
-}
-
 void SnapResource::setSnap(const QSharedPointer<QSnapdSnap>& snap)
 {
     Q_ASSERT(snap->name() == m_snap->name());
@@ -231,6 +235,8 @@ void SnapResource::setSnap(const QSharedPointer<QSnapdSnap>& snap)
     m_snap = snap;
     if (newSize)
         Q_EMIT sizeChanged();
+
+    Q_EMIT newSnap();
 }
 
 QDate SnapResource::releaseDate() const
@@ -325,3 +331,109 @@ QAbstractItemModel* SnapResource::plugs(QObject* p)
 
     return new PlugsModel(m_snap.data(), qobject_cast<SnapBackend*>(parent()), p);
 }
+
+QString SnapResource::appstreamId() const
+{
+    const QStringList ids
+#if defined(SNAP_COMMON_IDS)
+        = m_snap->commonIds()
+#endif
+    ;
+    return ids.isEmpty() ? QLatin1String("com.snap.") + m_snap->name() : ids.first();
+}
+
+QString SnapResource::channel() const
+{
+    auto req = client()->listOne(packageName());
+    req->runSync();
+    return req->error() ? QString() : req->snap()->trackingChannel();
+}
+
+void SnapResource::setChannel(const QString& channelName)
+{
+#ifdef SNAP_CHANNELS
+    Q_ASSERT(isInstalled());
+    auto request = client()->switchChannel(m_snap->name(), channelName);
+
+    const auto currentChannel = channel();
+    auto dest = new CallOnDestroy([this, currentChannel]() {
+        const auto newChannel = channel();
+        if (newChannel != currentChannel) {
+            Q_EMIT channelChanged(newChannel);
+        }
+    });
+
+    request->runAsync();
+    connect(request, &QSnapdRequest::complete, dest, &QObject::deleteLater);
+#endif
+}
+
+void SnapResource::refreshSnap()
+{
+    auto request = client()->find(QSnapdClient::FindFlag::MatchName, m_snap->name());
+    connect(request, &QSnapdRequest::complete, this, [this, request](){
+        if (request->error()) {
+            qWarning() << "error" << request->error() << ": " << request->errorString();
+            return;
+        }
+        Q_ASSERT(request->snapCount() == 1);
+        setSnap(QSharedPointer<QSnapdSnap>(request->snap(0)));
+    });
+    request->runAsync();
+}
+
+#ifdef SNAP_CHANNELS
+class Channels : public QObject
+{
+    Q_OBJECT
+    Q_PROPERTY(QList<QObject *> channels READ channels NOTIFY channelsChanged)
+
+public:
+    Channels(SnapResource* res, QObject* parent) : QObject(parent), m_res(res) {
+        if (res->snap()->channelCount() == 0)
+            res->refreshSnap();
+        else
+            refreshChannels();
+
+        connect(res, &SnapResource::newSnap, this, &Channels::refreshChannels);
+    }
+
+
+    void refreshChannels()
+    {
+        qDeleteAll(m_channels);
+
+        auto s = m_res->snap();
+        for(int i=0, c=s->channelCount(); i<c; ++i) {
+            auto channel = s->channel(i);
+            channel->setParent(this);
+            m_channels << channel;
+        }
+        Q_EMIT channelsChanged();
+    }
+
+    QList<QObject *> channels() const
+    {
+        return m_channels;
+    }
+
+Q_SIGNALS:
+    void channelsChanged();
+
+private:
+    QList<QObject*> m_channels;
+    SnapResource* const m_res;
+};
+
+#endif
+
+QObject * SnapResource::channels(QObject* parent)
+{
+#ifdef SNAP_CHANNELS
+    return new Channels(this, parent);
+#else
+    return nullptr;
+#endif
+}
+
+#include "SnapResource.moc"
