@@ -21,7 +21,7 @@
 
 #include "ResourcesProxyModel.h"
 
-#include <QDebug>
+#include "libdiscover_debug.h"
 #include <QMetaProperty>
 #include <utils.h>
 
@@ -136,7 +136,7 @@ void ResourcesProxyModel::removeDuplicates(QVector<AbstractResource *>& resource
         if (at == storedIds.end()) {
             storedIds[appstreamid] = it;
         } else {
-            qWarning() << "We should have sanitized the displayed resources. There is a bug";
+            qCWarning(LIBDISCOVER_LOG) << "We should have sanitized the displayed resources. There is a bug";
             Q_UNREACHABLE();
         }
     }
@@ -165,7 +165,7 @@ void ResourcesProxyModel::removeDuplicates(QVector<AbstractResource *>& resource
             if ((*it)->backend() == cab) {
                 **at = *it;
                 auto pos = index(*at - m_displayedResources.begin(), 0);
-                dataChanged(pos, pos);
+                Q_EMIT dataChanged(pos, pos);
             }
             it = resources.erase(it);
         }
@@ -231,13 +231,13 @@ void ResourcesProxyModel::setFiltersFromCategory(Category *category)
 
 void ResourcesProxyModel::fetchSubcategories()
 {
-    auto cats = (m_filters.category ? m_filters.category->subCategories() : CategoryModel::global()->rootCategories()).toList().toSet();
+    auto cats = kVectorToSet(m_filters.category ? m_filters.category->subCategories() : CategoryModel::global()->rootCategories());
 
     const int count = rowCount();
     QSet<Category*> done;
     for (int i=0; i<count && !cats.isEmpty(); ++i) {
         AbstractResource* res = m_displayedResources[i];
-        const auto found = res->categoryObjects(cats.toList().toVector());
+        const auto found = res->categoryObjects(kSetToVector(cats));
         done.unite(found);
         cats.subtract(found);
     }
@@ -261,7 +261,7 @@ void ResourcesProxyModel::invalidateFilter()
     }
 
     if (m_currentStream) {
-        qWarning() << "last stream isn't over yet" << m_filters << this;
+        qCWarning(LIBDISCOVER_LOG) << "last stream isn't over yet" << m_filters << this;
         delete m_currentStream;
     }
 
@@ -421,14 +421,14 @@ QVariant ResourcesProxyModel::roleToValue(AbstractResource* resource, int role)
         default: {
             QByteArray roleText = roleNames().value(role);
             if(Q_UNLIKELY(roleText.isEmpty())) {
-                qDebug() << "unsupported role" << role;
+                qCDebug(LIBDISCOVER_LOG) << "unsupported role" << role;
                 return {};
             }
             static const QMetaObject* m = &AbstractResource::staticMetaObject;
             int propidx = roleText.isEmpty() ? -1 : m->indexOfProperty(roleText.constData());
 
             if(Q_UNLIKELY(propidx < 0)) {
-                qWarning() << "unknown role:" << role << roleText;
+                qCWarning(LIBDISCOVER_LOG) << "unknown role:" << role << roleText;
                 return QVariant();
             } else
                 return m->property(propidx).read(resource);
@@ -468,7 +468,7 @@ void ResourcesProxyModel::sortedInsertion(const QVector<AbstractResource*> & _re
         return;
     }
 
-    for(auto resource: resources) {
+    for(auto resource: qAsConst(resources)) {
         const auto finder = [this](AbstractResource* resource, AbstractResource* res){ return lessThan(resource, res); };
         const auto it = std::upper_bound(m_displayedResources.constBegin(), m_displayedResources.constEnd(), resource, finder);
         const auto newIdx = it == m_displayedResources.constEnd() ? m_displayedResources.count() : (it - m_displayedResources.constBegin());
