@@ -20,7 +20,7 @@
 
 #include "SourcesModel.h"
 #include <QtGlobal>
-#include <QDebug>
+#include "libdiscover_debug.h"
 #include <QAction>
 #include "resources/AbstractResourcesBackend.h"
 #include "resources/AbstractSourcesBackend.h"
@@ -28,6 +28,7 @@
 Q_GLOBAL_STATIC(SourcesModel, s_sources)
 
 const auto DisplayName = "DisplayName";
+const auto SourcesBackendId = "SourcesBackend";
 
 class SourceBackendModel : public QAbstractListModel
 {
@@ -41,14 +42,11 @@ public:
         if (!index.isValid()) return {};
         switch(role) {
             case SourcesModel::ResourcesBackend: return QVariant::fromValue<QObject*>(m_backend);
-            case SourcesModel::SourcesBackend: return QVariant::fromValue<QObject*>(m_sources);
         }
         return {};
     }
     int rowCount(const QModelIndex & parent) const override { return parent.isValid() ? 0 : 1; }
 
-    AbstractSourcesBackend* m_sources = nullptr;
-
 private:
     AbstractResourcesBackend* m_backend;
 };
@@ -67,6 +65,8 @@ SourcesModel* SourcesModel::global()
 QHash<int, QByteArray> SourcesModel::roleNames() const
 {
     QHash<int, QByteArray> roles = KConcatenateRowsProxyModel::roleNames();
+    roles.insert(AbstractSourcesBackend::IdRole, "sourceId");
+    roles.insert(SourceNameRole, "sourceName");
     roles.insert(SourcesBackend, "sourcesBackend");
     roles.insert(ResourcesBackend, "resourcesBackend");
     return roles;
@@ -75,42 +75,41 @@ QHash<int, QByteArray> SourcesModel::roleNames() const
 void SourcesModel::addSourcesBackend(AbstractSourcesBackend* sources)
 {
     auto backend = qobject_cast<AbstractResourcesBackend*>(sources->parent());
-    auto b = addBackend(backend);
-    if (!b)
-        return;
 
-    b->m_sources = sources;
     auto m = sources->sources();
     m->setProperty(DisplayName, backend->displayName());
+    m->setProperty(SourcesBackendId, qVariantFromValue<QObject*>(sources));
     addSourceModel(m);
 }
 
-
-SourceBackendModel* SourcesModel::addBackend(AbstractResourcesBackend* backend)
+const QAbstractItemModel * SourcesModel::modelAt(const QModelIndex& index) const
 {
-    Q_ASSERT(backend);
-    const auto inSourcesModel = "InSourcesModel";
-    if (backend->dynamicPropertyNames().contains(inSourcesModel))
-        return nullptr;
-    backend->setProperty(inSourcesModel, 1);
-
-    auto b = new SourceBackendModel(backend);
-    b->setProperty(DisplayName, backend->displayName());
-    addSourceModel(b);
-    return b;
+    const auto sidx = mapToSource(index);
+    return sidx.model();
 }
 
 QVariant SourcesModel::data(const QModelIndex& index, int role) const
 {
     if (!index.isValid()) return {};
-    else if (role == SourceNameRole) {
-        const auto sidx = mapToSource(index);
-        const auto model = sidx.model();
-        auto ret = model->property(DisplayName);
-        return ret;
-    } else {
-        return KConcatenateRowsProxyModel::data(index, role);
+    switch (role) {
+        case SourceNameRole:
+            return modelAt(index)->property(DisplayName);
+        case SourcesBackend:
+            return modelAt(index)->property(SourcesBackendId);
+        default:
+            return KConcatenateRowsProxyModel::data(index, role);
     }
 }
 
+AbstractSourcesBackend * SourcesModel::sourcesBackendByName(const QString& id) const
+{
+    for(int i = 0, c = rowCount(); i < c; ++i) {
+        const auto idx = index(i, 0);
+        if (idx.data(SourceNameRole) == id) {
+            return qobject_cast<AbstractSourcesBackend *>(idx.data(SourcesBackend).value<QObject*>());
+        }
+    }
+    return nullptr;
+}
+
 #include "SourcesModel.moc"
